==> ajh-facade-1.0.1-20210909.042500-29-sources.jar: com/bizvane/ajhfacade/rpc/OdersRpcService.java <==
package com.bizvane.ajhfacade.rpc;
import com.bizvane.ajhfacade.models.po.Comments;
import com.bizvane.ajhfacade.models.po.Orders;
import com.bizvane.ajhfacade.vo.InstallVO;
import com.bizvane.utils.responseinfo.ResponseData;
import com.github.pagehelper.PageInfo;
import org.springframework.cloud.openfeign.FeignClient;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RequestParam;
import java.util.List;
@FeignClient(value = "${feign.client.ajh.name}", path = "${feign.client.ajh.path}/ordersRpc")
public interface OdersRpcService {

    @RequestMapping(value = "/getProjectListRpc", method = RequestMethod.POST)
    PageInfo selectAftermarket(@RequestBody InstallVO installVO);

//    @RequestMapping(value = "/distributionInstall")
//    ResponseData distributionInstall(@RequestParam(value = "ostatus", required = false) Integer ostatus, @RequestParam(value = "userId") Long userId);
//
//    @RequestMapping(value = "/insert")
//    ResponseData insert(@RequestBody(required = false) Comments comments);
//
//    @RequestMapping(value = "/userCancel")
//    ResponseData userCancel(@RequestBody(required = false) Orders orders);
//
//    @RequestMapping(value = "/selectById")
//    ResponseData selectById(@RequestParam("id") Integer id);
//
//    @RequestMapping(value = "/viewAudit")
//    ResponseData viewAudit(@RequestParam(value="id") Integer id);
//
//    @RequestMapping(value = "/selectProject")
//    ResponseData selectProject();
//
//    @RequestMapping(value = "/addRepairOrder")
//    ResponseData addRepairOrder(@RequestBody Orders orders,@RequestParam(value = "projectID") int [] projectID,@RequestParam(value = "id") int id);

}

==> ajh-facade-1.0.1-20210910.082339-33-sources.jar: com/bizvane/ajhfacade/rpc/OdersRpcService.java <==
package com.bizvane.ajhfacade.rpc;
import com.bizvane.ajhfacade.models.po.Comments;
import com.bizvane.ajhfacade.models.po.Orders;
import com.bizvane.ajhfacade.vo.InstallVO;
import com.bizvane.utils.responseinfo.ResponseData;
import com.github.pagehelper.PageInfo;
import org.springframework.cloud.openfeign.FeignClient;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RequestParam;
import java.util.List;
@FeignClient(value = "${feign.client.ajh.name}", path = "${feign.client.ajh.path}/ordersRpc")
public interface OdersRpcService {

    @RequestMapping(value = "/getOrdersListRpc", method = RequestMethod.POST)
    ResponseData<List<Orders>> selectAftermarket(@RequestBody  InstallVO installVO);

//    @RequestMapping(value = "/distributionInstall")
//    ResponseData distributionInstall(@RequestParam(value = "ostatus", required = false) Integer ostatus, @RequestParam(value = "userId") Long userId);
//
//    @RequestMapping(value = "/insert")
//    ResponseData insert(@RequestBody(required = false) Comments comments);
//
//    @RequestMapping(value = "/userCancel")
//    ResponseData userCancel(@RequestBody(required = false) Orders orders);
//
//    @RequestMapping(value = "/selectById")
//    ResponseData selectById(@RequestParam("id") Integer id);
//
//    @RequestMapping(value = "/viewAudit")
//    ResponseData viewAudit(@RequestParam(value="id") Integer id);
//
//    @RequestMapping(value = "/selectProject")
//    ResponseData selectProject();
//
//    @RequestMapping(value = "/addRepairOrder")
//    ResponseData addRepairOrder(@RequestBody Orders orders,@RequestParam(value = "projectID") int [] projectID,@RequestParam(value = "id") int id);

}
